@@ -1,6 +1,6 @@
 data_authors <- function(pkg = ".", roles = default_roles()) {
   pkg <- as_pkgdown(pkg)
-  author_info <- data_author_info(pkg)
+  author_info <- pkg$meta$authors %||% list()
 
   all <- pkg %>%
     pkg_authors() %>%
@@ -46,27 +46,6 @@ pkg_authors <- function(pkg, role = NULL) {
   }
 }
 
-
-data_author_info <- function(pkg = ".") {
-  pkg <- as_pkgdown(pkg)
-
-  defaults <- list(
-    "Hadley Wickham" = list(
-      href = "http://hadley.nz"
-    ),
-    "RStudio" = list(
-      href = "https://www.rstudio.com",
-      html = "<img src='https://www.tidyverse.org/rstudio-logo.svg' alt='RStudio' width='72' />"
-    ),
-    "R Consortium" = list(
-      href = "https://www.r-consortium.org"
-    )
-  )
-
-  utils::modifyList(defaults, pkg$meta$authors %||% list())
-}
-
-
 data_home_sidebar_authors <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
   roles <- pkg$meta$authors$sidebar$roles %||% default_roles()
@@ -77,14 +56,12 @@ data_home_sidebar_authors <- function(pkg = ".") {
   bullets <- c(
     markdown_text_inline(
       pkg$meta$authors$sidebar$before,
-      pkg = pkg,
-      where = c("authors", "sidebar", "before")
+      pkgdown_field(pkg, c("authors", "sidebar", "before"))
     ),
     authors,
     markdown_text_inline(
       pkg$meta$authors$sidebar$after,
-      pkg = pkg,
-      where = c("authors", "sidebar", "after")
+      pkgdown_field(pkg, c("authors", "sidebar", "after"))
     )
   )
 
@@ -101,8 +78,8 @@ data_authors_page <- function(pkg) {
     authors = data_authors(pkg)$all
   )
 
-  data$before <- markdown_text_block(pkg$meta$authors$before, pkg = pkg)
-  data$after <- markdown_text_block(pkg$meta$authors$after, pkg = pkg)
+  data$before <- markdown_text_block(pkg$meta$authors$before)
+  data$after <- markdown_text_block(pkg$meta$authors$after)
 
   return(data)
 }
@@ -119,8 +96,7 @@ author_name <- function(x, authors, pkg) {
   if (!is.null(author$html)) {
     name <- markdown_text_inline(
       author$html,
-      pkg = pkg,
-      where = c("authors", name, "html")
+      pkgdown_field(pkg, c("authors", name, "html"))
     )
   }
 
