@@ -1,15 +1,15 @@
-markdown_text <- function(text, pkg = list(), ...) {
+markdown_text <- function(text, ...) {
   if (identical(text, NA_character_) || is.null(text)) {
     return(NULL)
   }
 
   md_path <- withr::local_tempfile()
   write_lines(text, md_path)
-  markdown_path_html(md_path, ..., pkg = pkg)
+  markdown_path_html(md_path, ...)
 }
 
-markdown_text_inline <- function(text, pkg = list(), where = "<inline>", ...) {
-  html <- markdown_text(text, pkg = pkg, ...)
+markdown_text_inline <- function(text, where = "<inline>", ...) {
+  html <- markdown_text(text, ...)
   if (is.null(html)) {
     return()
   }
@@ -18,8 +18,8 @@ markdown_text_inline <- function(text, pkg = list(), where = "<inline>", ...) {
   if (length(children) > 1) {
     abort(
       sprintf(
-        "Can't use a block element here, need an inline element: \n %s \n%s",
-        what = pkgdown_field(pkg = pkg, where),
+        "Can't use a block element in %s, need an inline element: \n%s",
+        where,
         text
       )
     )
@@ -28,8 +28,8 @@ markdown_text_inline <- function(text, pkg = list(), where = "<inline>", ...) {
   paste0(xml2::xml_contents(children), collapse="")
 }
 
-markdown_text_block <- function(text, pkg = list(), ...) {
-  html <- markdown_text(text, pkg = pkg, ...)
+markdown_text_block <- function(text, ...) {
+  html <- markdown_text(text, ...)
   if (is.null(html)) {
     return()
   }
@@ -38,8 +38,8 @@ markdown_text_block <- function(text, pkg = list(), ...) {
   paste0(as.character(children, options = character()), collapse = "")
 }
 
-markdown_body <- function(path, strip_header = FALSE, pkg = list()) {
-  xml <- markdown_path_html(path, strip_header = strip_header, pkg = pkg)
+markdown_body <- function(path, strip_header = FALSE) {
+  xml <- markdown_path_html(path, strip_header = strip_header)
 
   # Extract body of html - as.character renders as xml which adds
   # significant whitespace in tags like pre
@@ -58,7 +58,7 @@ markdown_body <- function(path, strip_header = FALSE, pkg = list()) {
   )
 }
 
-markdown_path_html <- function(path, strip_header = FALSE, pkg = list()) {
+markdown_path_html <- function(path, strip_header = FALSE) {
   html_path <- withr::local_tempfile()
   convert_markdown_to_html(path, html_path)
   xml <- xml2::read_html(html_path, encoding = "UTF-8")
