@@ -1,18 +1,95 @@
+test_that("data_news works as expected for h1 & h2", {
+  skip_if_no_pandoc()
+
+  lines_h1 <- c(
+    "# testpackage 1.0.0.9000", "",
+    "* bullet (#222 @someone)", "",
+    "# testpackage 1.0.0", "",
+    "## sub-heading", "",
+    "* first thing (#111 @githubuser)", "",
+    "* second thing", ""
+  )
+  lines_h2 <- gsub("^#", "##", lines_h1)
+
+  pkg <- local_pkgdown_site(meta = "
+    template:
+      bootstrap: 5
+  ")
+
+  write_lines(lines_h1, file.path(pkg$src_path, "NEWS.md"))
+  expect_snapshot_output(data_news(pkg)[c("version", "page", "anchor")])
+
+  write_lines(lines_h2, file.path(pkg$src_path, "NEWS.md"))
+  expect_snapshot_output(data_news(pkg)[c("version", "page", "anchor")])
+})
+
+
+test_that("multi-page news are rendered", {
+  skip_if_no_pandoc()
+
+  pkg <- local_pkgdown_site(meta = "
+    news:
+      one_page: false
+    "
+  )
+  write_lines(file.path(pkg$src_path, "NEWS.md"), text = c(
+    "# testpackage 2.0", "",
+    "* bullet (#222 @someone)", "",
+    "# testpackage 1.1", "",
+    "* bullet (#222 @someone)", "",
+    "# testpackage 1.0.1", "",
+    "* bullet (#222 @someone)", "",
+    "# testpackage 1.0.0", "",
+    "## sub-heading", "",
+    "* first thing (#111 @githubuser)", "",
+    "* second thing"
+  ))
+
+  expect_snapshot_output(data_news(pkg)[c("version", "page", "anchor")])
+  expect_output(build_news(pkg))
+
+  # test that index links are correct
+  lines <- read_lines(path(pkg$dst_path, "news", "index.html"))
+  expect_true(any(grepl("<a href=\"news-2.0.html\">Version 2.0</a>", lines)))
+
+  # test single page structure
+  lines <- read_lines(path(pkg$dst_path, "news", "news-1.0.html"))
+  expect_true(any(grepl("<h1 data-toc-skip>Changelog <small>1.0</small></h1>", lines)))
+})
+
+
 test_that("github links are added to news items", {
   skip_if_no_pandoc()
 
-  pkg <- as_pkgdown(
-    test_path("assets/news-github-links"),
-    list(news = list(cran_dates = FALSE))
+  temp_pkg <- list(
+    src_path = withr::local_tempdir(pattern = "pkgdown-news"),
+    bs_version = 5,
+    repo = list(
+      url = list(
+        home = "https://github.com/r-lib/pkgdown",
+        user = "https://github.com/",
+        issue = "https://github.com/r-lib/pkgdown/issues/"
+      )
+    )
   )
-  news_tbl <- data_news(pkg)
+
+  write_lines(
+    c(
+      "# testpackage 0.1.0", "",
+      "## Major changes", "",
+      "- Bug fixes (@hadley, #100)", "",
+      "- Merges (@josue-rodriguez)"
+    ),
+    file.path(temp_pkg$src_path, "NEWS.md")
+  )
+  news_tbl <- data_news(temp_pkg)
   html <- xml2::read_xml(news_tbl$html)
 
   expect_equal(
     xpath_attr(html, ".//a", "href"),
     c(
       "https://github.com/hadley",
-      "https://github.com/hadley/pkgdown/issues/100",
+      "https://github.com/r-lib/pkgdown/issues/100",
       "https://github.com/josue-rodriguez"
     )
   )
@@ -23,11 +100,6 @@ test_that("pkg_timeline fails cleanly for unknown package", {
   expect_null(pkg_timeline("__XYZ__"))
 })
 
-test_that("pkg_timeline returns NULL if CRAN dates suppressed", {
-  skip_on_cran()
-  expect_null(pkg_timeline(list(meta = list(news = list(cran_dates = FALSE)))))
-})
-
 test_that("correct timeline for first ggplot2 releases", {
   skip_on_cran()
 
@@ -47,24 +119,6 @@ test_that("determines page style from meta", {
   expect_equal(news_style(meta = list(news = list(list(one_page = FALSE)))), "multi")
 })
 
-test_that("multi-page news are rendered", {
-  skip_if_no_pandoc()
-
-  pkg <- local_pkgdown_site(test_path("assets/news-multi-page"), '
-    news:
-      cran_dates: false
-  ')
-  expect_output(build_news(pkg))
-
-  # test that index links are correct
-  lines <- read_lines(path(pkg$dst_path, "news", "index.html"))
-  expect_true(any(grepl("<a href=\"news-2.0.html\">Version 2.0</a>", lines)))
-
-  # test single page structure
-  lines <- read_lines(path(pkg$dst_path, "news", "news-1.0.html"))
-  expect_true(any(grepl("<h1 data-toc-skip>Changelog <small>1.0</small></h1>", lines)))
-})
-
 # news_title and version_page -----------------------------------------------
 
 test_that("can recognise common forms of title", {
@@ -132,3 +186,47 @@ test_that("news headings get class and release date", {
   tweak_news_heading(html, version = "1.0", timeline = timeline, bs_version = 4)
   expect_snapshot_output(xpath_xml(html, "//div"))
 })
+
+# Header checks ----------------------------------------------------------
+test_that("clear error for bad hierarchy - bad nesting", {
+  temp_pkg <- list(
+    src_path = withr::local_tempdir(pattern = "pkgdown-news"),
+    bs_version = 5
+  )
+
+  write_lines(
+    c(
+      "### testpackage 1.0.0.9000", "",
+      "* bullet (#222 @someone)", "",
+      "# testpackage 1.0.0", "",
+      "## sub-heading", "",
+      "* first thing (#111 @githubuser)", "",
+      "* second thing", ""
+    ),
+    file.path(temp_pkg$src_path, "NEWS.md")
+  )
+
+  expect_snapshot_error(data_news(temp_pkg))
+})
+
+test_that("clear error for bad hierarchy - h3", {
+  temp_pkg <- list(
+    src_path = withr::local_tempdir(pattern = "pkgdown-news"),
+    bs_version = 5
+  )
+
+  write_lines(
+    c(
+      "### testpackage 1.0.0.9000", "",
+      "* bullet (#222 @someone)", "",
+      "### testpackage 1.0.0", "",
+      "#### sub-heading", "",
+      "* first thing (#111 @githubuser)", "",
+      "* second thing", ""
+    ),
+    file.path(temp_pkg$src_path, "NEWS.md")
+  )
+
+  expect_snapshot_error(data_news(temp_pkg))
+})
+
