@@ -67,19 +67,36 @@ test_that("can control articles navbar through articles meta", {
 })
 
 test_that("data_navbar() works by default", {
-  pkg <- as_pkgdown(test_path("assets/news-multi-page"))
+  pkg <- local_pkgdown_site(meta = list(
+    news = list(one_page = FALSE, cran_dates = FALSE),
+    repo = list(url = list(home = "https://github.com/r-lib/pkgdown/"))
+  ))
+  write_lines(file.path(pkg$src_path, "NEWS.md"), text = c(
+    "# testpackage 2.0", "",
+    "* bullet (#222 @someone)"
+  ))
+
+  pkg <- local_pkgdown_site(pkg)
   expect_snapshot(data_navbar(pkg))
 })
 
 test_that("data_navbar() can re-order default elements", {
-  pkg <- as_pkgdown(test_path("assets/news-multi-page"))
+  pkg <- local_pkgdown_site(meta = list(
+    repo = list(url = list(home = "https://github.com/r-lib/pkgdown/"))
+  ))
+  file.create(file.path(pkg$src_path, "NEWS.md"))
+
   pkg$meta$navbar$structure$right <- c("news")
   pkg$meta$navbar$structure$left <- c("github", "reference")
   expect_snapshot(data_navbar(pkg))
 })
 
-test_that("data_navbar()can remove elements", {
-  pkg <- as_pkgdown(test_path("assets/news-multi-page"))
+test_that("data_navbar() can remove elements", {
+  pkg <- local_pkgdown_site(meta = list(
+    repo = list(url = list(home = "https://github.com/r-lib/pkgdown/"))
+  ))
+  file.create(file.path(pkg$src_path, "NEWS.md"))
+
   pkg$meta$navbar$structure$left <- c("github")
   pkg$meta$navbar$structure$right <- c("reference")
   expect_snapshot(data_navbar(pkg))
